==> haskell-unliftio-core-0.1.0.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.0.0
id: unliftio-core-0.1.0.0-9rQX9ZUGZDTAHFduIwCNuu
key: unliftio-core-0.1.0.0-9rQX9ZUGZDTAHFduIwCNuu
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/monad-unlift/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the README.md file for details
category: Control
author: Michael Snoyman, Francesco Mazzoli
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
abi: 81694956f3a90ca47aa628d6ec33109b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/unliftio-core-0.1.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/unliftio-core-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/unliftio-core-0.1.0.0
hs-libraries: HSunliftio-core-0.1.0.0-9rQX9ZUGZDTAHFduIwCNuu
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.1.1.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.1.0
id: unliftio-core-0.1.1.0-3wrHy3Ijr0BBoYMyh4oX3g
key: unliftio-core-0.1.1.0-3wrHy3Ijr0BBoYMyh4oX3g
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/unliftio/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>
category: Control
author: Michael Snoyman, Francesco Mazzoli
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
abi: 80eb3168f42ca410245c0d9b99385d79
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/unliftio-core-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/unliftio-core-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/unliftio-core-0.1.1.0
hs-libraries: HSunliftio-core-0.1.1.0-3wrHy3Ijr0BBoYMyh4oX3g
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
